; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a GOES GeoTiff image plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "goes_geotiff_plot.pro" and run it like this::
;       IDL> .RUN goes_geotiff_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 27 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO GOES_GeoTiff_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   ; GOES East and West GeoTiff image can be downloaded from this
   ; NOAA web page: http://www.osdpd.noaa.gov/ml/gis/index.html.
   goesGeoTiffFile = 'GoesEast04I23451615.tif'
   
   ; Create a map coordinate object and read the data at the same time.
   mapCoord = cgGeoMap(goesGeoTiffFile, Image=image)
   
   ; Create a display window. Make aspect ratio of the window match
   ; the image.
   cgDisplay, Aspect=image, 650
   
   ; Display the image with a two-precent histogram stretch. 
   cgImage, image, Stretch
   
   ; Set the POSITION of the map coordinate object to fill the window.
   mapCoord -> SetProperty, Position=[0,0,1,1], /NoBorder, /Draw

   ; Add continental outlines.
   cgMap_Continents, Color='Violet', Map=mapCoord
   
   ; Add map grid lines.
   cgMap_Grid, COLOR='yellow', MAP=mapCoord, LatDelta=15, LonDelta=15, $
       LatLab=-97.5, LonLab=7.5, /LABEL   
   
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  GOES_GeoTiff_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'GOES_GeoTiff_Plot',  WBackground='white', WAspect=1.0, $
    WTitle='GOES Image in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'goes_geotiff_plot.ps'
  GOES_GeoTiff_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'goes_geotiff_plot.ps', /PNG, /Portrait

END